@@ -16,11 +16,11 @@ package WebDyne::Install;
 
 #  Compiler Pragma
 #
-sub BEGIN	{ $^W=0 };
-use strict	qw(vars);
-use vars	qw($VERSION @EXPORT_OK @ISA);
+sub BEGIN {$^W=0}
+use strict qw(vars);
+use vars qw($VERSION @EXPORT_OK @ISA);
 use warnings;
-no  warnings	qw(uninitialized);
+no warnings qw(uninitialized);
 
 
 #  Export the message function
@@ -51,7 +51,7 @@ use Config;
 
 #  Version information
 #
-$VERSION='1.243';
+$VERSION='1.244';
 
 
 #  Debug
@@ -80,7 +80,7 @@ sub message {
     return if $ENV{'SILENT'};
     @_ || return print $/;
     my $message=
-	sprintf(join('[%sinstall] - ',  undef, ucfirst(shift())).$/, $Uninstall_fg && 'un', @_);
+        sprintf(join('[%sinstall] - ', undef, ucfirst(shift())) . $/, $Uninstall_fg && 'un', @_);
     $message=~s/\.?$/\./;
     print $message;
 
@@ -100,7 +100,7 @@ sub uninstall {
     #  Set uninstall flag
     #
     $Uninstall_fg++;
-    message ;
+    message;
 
 
     #  Get cache dn
@@ -111,18 +111,18 @@ sub uninstall {
     #  Delete cache files and remove if empty
     #
     if ($cache_dn && (-d $cache_dn)) {
-	my @file_cn=glob(File::Spec->catfile($cache_dn, '*'));
-	message "removing cache files from '$cache_dn'";
+        my @file_cn=glob(File::Spec->catfile($cache_dn, '*'));
+        message "removing cache files from '$cache_dn'";
         foreach my $fn (grep {/\w{32}(\.html)?$/} @file_cn) {
-            unlink $fn; #don't error here if problems, user will never see it
+            unlink $fn;    #don't error here if problems, user will never see it
         }
-	message "removing cache directory '$cache_dn'";
-	rmdir $cache_dn unless ($cache_dn eq File::Spec->tmpdir);
+        message "removing cache directory '$cache_dn'";
+        rmdir $cache_dn unless ($cache_dn eq File::Spec->tmpdir);
     }
     if ($prefix) {
-	message "updating perl5lib config.";
-	&perl5lib::del($prefix) if $prefix;
-	rmdir($prefix) if $prefix;
+        message "updating perl5lib config.";
+        &perl5lib::del($prefix) if $prefix;
+        rmdir($prefix) if $prefix;
     }
 
 
@@ -143,24 +143,25 @@ sub install {
     my (undef, $prefix)=@_;
     $prefix=undef if ($prefix eq $Config{'prefix'});
 
-    message ;
+    message;
     message sprintf(q[installation source directory '%s'.], $prefix || $Config{'prefix'});
 
 
     #  Create the cache dir
     #
-    unless  (-d (my $cache_dn=&cache_dn($prefix))) {
+    unless (-d (my $cache_dn=&cache_dn($prefix))) {
 
-	#  Make
-	#
-	message "creating cache directory '$cache_dn'.";
-	File::Path::mkpath($cache_dn, 0, 0755) || do {
-	    return err("unable to create dir $cache_dn") unless (-d $cache_dn) };
+        #  Make
+        #
+        message "creating cache directory '$cache_dn'.";
+        File::Path::mkpath($cache_dn, 0, 0755) || do {
+            return err ("unable to create dir $cache_dn") unless (-d $cache_dn)
+        };
 
     }
     else {
 
-	message "using existing cache directory '$cache_dn'.";
+        message "using existing cache directory '$cache_dn'.";
 
     }
 
@@ -191,34 +192,34 @@ sub cache_dn {
     #  Get any prefix supplied
     #
     my $prefix=shift();
-    
+
 
     #  Var to hold returned result
     #
     my $cache_dn;
-    
+
 
     #  Use user specified location
     #
     if ($WEBDYNE_CACHE_DN) {
-	$cache_dn=$WEBDYNE_CACHE_DN;
+        $cache_dn=$WEBDYNE_CACHE_DN;
     }
-    
+
     #  If installed into custom location via PREFIX, but not the same
     #  as the Perl instal,
     elsif ($prefix && ($prefix ne $Config{'prefix'})) {
-	$cache_dn=File::Spec->catdir($prefix, 'cache');
+        $cache_dn=File::Spec->catdir($prefix, 'cache');
     }
-    
-    
+
+
     #  No prefix spec'd, or prefix is the same as Perl install dir, so
     #  use default location
     #
     else {
         $cache_dn=$DIR_CACHE_DEFAULT;
     }
-    
-    
+
+
     #  Done return result
     #
     return $cache_dn;
